package com.uavps.system.service;

import com.uavps.system.domain.UavpsAlgorithmParameter;

import java.util.List;

/**
 * 算法参数信息Service接口
 *
 * @author ruoyi
 * @date 2025-03-27
 */
public interface IUavpsAlgorithmParameterService {
    /**
     * 查询算法参数信息
     *
     * @param id 算法参数信息主键
     * @return 算法参数信息
     */
    public UavpsAlgorithmParameter selectUavpsAlgorithmParameterById(Long id);

    /**
     * 查询算法参数信息列表
     *
     * @param uavpsAlgorithmParameter 算法参数信息
     * @return 算法参数信息集合
     */
    public List<UavpsAlgorithmParameter> selectUavpsAlgorithmParameterList(UavpsAlgorithmParameter uavpsAlgorithmParameter);

    /**
     * 新增算法参数信息
     *
     * @param uavpsAlgorithmParameter 算法参数信息
     * @return 结果
     */
    public int insertUavpsAlgorithmParameter(UavpsAlgorithmParameter uavpsAlgorithmParameter);

    /**
     * 修改算法参数信息
     *
     * @param uavpsAlgorithmParameter 算法参数信息
     * @return 结果
     */
    public int updateUavpsAlgorithmParameter(UavpsAlgorithmParameter uavpsAlgorithmParameter);

    /**
     * 批量删除算法参数信息
     *
     * @param ids 需要删除的算法参数信息主键集合
     * @return 结果
     */
    public int deleteUavpsAlgorithmParameterByIds(Long[] ids);

    /**
     * 删除算法参数信息信息
     *
     * @param id 算法参数信息主键
     * @return 结果
     */
    public int deleteUavpsAlgorithmParameterById(Long id);

    public String initAlgorithmParams(Long id);
}
